(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24281,        516]*)
(*NotebookOutlinePosition[     24987,        540]*)
(*  CellTagsIndexPosition[     24943,        536]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(\(\( (*\ setup\ arrays\ *) \)\(\[IndentingNewLine]\)\(Off[
      General::spell1]; Off[General::spell];\[IndentingNewLine]
    Array[k, 10]; Array[g, 10]; Array[s, 10]; Array[r, 10]; Array[stemp, 10]; 
    Array[rtemp, 10]; Array[sb, 10]; Array[rb, 10]; Array[kb, 10]; 
    Array[gb, 10];\[IndentingNewLine]
    \(error = 0.000001;\)\  (*\ 
      target\ accuracy\ of\ calculations\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ USER\ INPUT\ *) \[IndentingNewLine]
    n = 4; beta = 5; eta = 2; alpha = 3;\ \[IndentingNewLine]
    theta = 0.5; \  (*\ 
      Intermediate\ good\ price\ *) \[IndentingNewLine]type = 1; \  (*\ 
      type\ 1\ merges\ upstream\ and\ downstream, \ 
      type\ 2\ merges\ downstream, \ 
      type\ 3\ merges\ upstream\ *) \[IndentingNewLine]a = 1/alpha; \ \  (*\ 
      The\ value\ a\ can\ be\ set\ to\ zero\ to\ produce\ the\ special\ case\ \
of\ infinite\ elasticity, \ 
      use\ negative\ alpha\ *) \[IndentingNewLine]\[IndentingNewLine] (*\ 
      Set\ market\ shares\ s\ is\ the\ same\ notation\ as\ the\ paper, \ 
      r\ is\ sigma\ *) \[IndentingNewLine]s[1] = 0.4; 
    r[1] = 0.1;\[IndentingNewLine]
    s[2] = 0.3; r[2] = 0.2;\[IndentingNewLine]
    s[3] = 0.2; r[3] = 0.3;\[IndentingNewLine]
    s[4] = 0.1; r[4] = 0.4;\[IndentingNewLine]
    s[5] = 0; \ r[5] = 0;\[IndentingNewLine]
    s[6] = 0; \ r[6] = 0;\[IndentingNewLine]
    s[7] = 0; \ r[7] = 0;\[IndentingNewLine]
    s[8] = 0; \ r[8] = 0;\[IndentingNewLine]
    s[9] = 0; \ r[9] = 0;\[IndentingNewLine]
    s[10] = 0; \ 
    r[10] = 0;\[IndentingNewLine]\[IndentingNewLine] (*\ 
      END\ USER\ INPUT\ *) \[IndentingNewLine]\[IndentingNewLine] (*\ 
      Clean\ the\ data\ *) \[IndentingNewLine]
    n = IntegerPart[n]; 
    If[n < 1, Print["\<Negative n reset to 3\>"]; n = 3];\[IndentingNewLine]
    \(If[type \[NotEqual] 1 && type \[NotEqual] 2 && type \[NotEqual] 3, 
        type = 1; 
        Print["\<Error: Illegal Merger Type\>"]];\)\[IndentingNewLine]
    \(If[a < 0, a = 0];\)\[IndentingNewLine]
    \(If[beta \[LessEqual] 0, beta = 1; 
        Print["\<Error: Downstream cost elasticities must be positive \
numbers.\>"]];\)\[IndentingNewLine]
    \(If[eta \[LessEqual] 0, eta = 1; 
        Print["\<Error: Upstream cost elasticities must be positive \
numbers.\>"]];\)\[IndentingNewLine]
    \(If[theta \[LessEqual] 0 || theta \[GreaterEqual] 1, theta = 0.5; 
        Print["\<Error: By definition, 0<theta<1.\>"]];\)\[IndentingNewLine]\
\[IndentingNewLine]
    \(Do[If[s[i] < 0, s[i] = 0]; 
        If[r[i] < 0, r[i] = 0], {i, 1, n}];\)\[IndentingNewLine]
    ssum = Sum[s[i], {i, 1, n}]; 
    rsum = Sum[r[i], {i, 1, n}];\[IndentingNewLine]
    \(If[Abs[ssum - 1.0] > 0.0001, 
        Print["\<Error: Downstream shares don't sum to one, rescaled\>"]];\)\
\[IndentingNewLine]
    \(If[Abs[rsum - 1.0] > 0.0001, 
        Print["\<Error: Upstream shares don't sum to one, rescaled\>"]];\)\
\[IndentingNewLine]
    \(If[ssum \[LessEqual] 0, 
        Print["\<Error: Check downstream market shares.\>"]; s[1] = 1; 
        ssum = 1; n = 1];\)\[IndentingNewLine]
    \(If[rsum \[LessEqual] 0, 
        Print["\<Error: Check upstream market shares.\>"]; r[1] = 1; 
        rsum = 1; n = 1];\)\[IndentingNewLine]
    \(If[ssum \[NotEqual] 1, 
        Do[s[i] = s[i]/ssum, {i, 1, n}]];\)\[IndentingNewLine]
    \(If[rsum \[NotEqual] 1, 
        Do[r[i] = r[i]/rsum, {i, 1, n}]];\)\[IndentingNewLine]
    \(If[s[n] \[Equal] 0 && r[n] \[Equal] 0, 
        Print["\<Error: Check the number of firms n = \>", 
          n]];\)\[IndentingNewLine]\[IndentingNewLine]
    \(If[s[1] + s[2] \[Equal] 1 && r[1] + r[2] \[Equal] 1, 
        Print["\<Error: The solution algorithm can't handle a merger to \
complete monopoly. s3 set to 0.01\>"]; n = 3; s[3] = 0.01; r[3] = 0.0; 
        s[1] = 0.99*s[1]; 
        s[2] = 0.99*s[2]];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Define\ psi, \ chi\ functions\ *) \[IndentingNewLine] (*\ 
      psi\ and\ chi\ are\ the\ same\ functions\ from\ the\ appendix\ *) \n
    psi[th_, st_, rt_] := 
      Min[1 - th, \((\((1 - th)\)/
              beta)\)*\((\((th*\((st - rt)\)/eta)\) + \((a*
                    st*\((1 - rt)\))\))\)/\((\((a*\((1 - st)\)*\((1 - 
                        rt)\))\) + \((\((1 - th)\)*\((1 - rt)\)/
                      beta)\) + \((th*\((1 - st)\)/
                      eta)\))\)]\[IndentingNewLine]
    chi[th_, st_, rt_] := 
      Min[th, \((th/
              eta)\)*\((\((\((1 - th)\)*\((rt - st)\)/beta)\) + \((a*
                    rt*\((1 - st)\))\))\)/\((\((a*\((1 - st)\)*\((1 - 
                        rt)\))\) + \((\((1 - th)\)*\((1 - rt)\)/
                      beta)\) + \((th*\((1 - st)\)/
                      eta)\))\)]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Compute\ capital\ levels\ k, \ 
      g\ for\ q = 1\ *) \[IndentingNewLine] (*\ 
      k\ is\ the\ same\ notation\ as\ the\ paper, \ 
      g\ is\ gamma\ *) \[IndentingNewLine]
    \(Do[k[
            i] = \((\((1 - theta - 
                    psi[theta, s[i], r[i]])\)^\((\(-beta\))\))\)*
            s[i]; \[IndentingNewLine]g[
            i] = \((\((theta - chi[theta, s[i], r[i]])\)^\((\(-eta\))\))\)*
            r[i], {i, 1, n}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      store\ starting\ values\ *) \[IndentingNewLine]
    \(Do[sb[i] = s[i]; rb[i] = r[i]; kb[i] = k[i]; 
        gb[i] = g[i], {i, 1, n}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Perform\ Merger\ on\ capitals, \ 
      estimate\ shares\ *) \[IndentingNewLine]
    \(If[type == 1, k[1] = k[1] + k[2]; k[2] = 0; g[1] = g[1] + g[2]; 
        g[2] = 0; s[1] = s[1] + s[2]; s[2] = 0; r[1] = r[1] + r[2]; 
        r[2] = 0];\)\[IndentingNewLine]
    \(If[type == 2, k[1] = k[1] + k[2]; k[2] = 0; s[1] = s[1] + s[2]; 
        s[2] = 0];\)\[IndentingNewLine]
    \(If[type == 3, g[1] = g[1] + g[2]; g[2] = 0; r[1] = r[1] + r[2]; 
        r[2] = 0];\)\[IndentingNewLine] (*\ stemp, \ 
      rtemp\ will\ be\ share\ estimates\ to\ iterate\ to\ a\ solution\ of\ \
the\ new\ shares\ *) \[IndentingNewLine]
    Do[stemp[i] = s[i]; 
      rtemp[i] = r[i], {i, 1, n}]\[IndentingNewLine]\[IndentingNewLine]
    thetastart = theta; \  (*\ 
      initial\ guess\ for\ the\ intermediate\ good\ price\ \
*) \[IndentingNewLine]\[IndentingNewLine] (*\ 
      This\ do\ loop\ computes\ shares, \ 
      iterate\ to\ find\ a\ solution\ *) \[IndentingNewLine]Do[\ \ \
\[IndentingNewLine]qtemp[
          tx_] := \((Sum[\((\((1 - tx - psi[tx, stemp[i], rtemp[i]])\)^
                    beta)\)*k[i], {i, 1, 
                n}])\)^\((1/\((1 + 
                  a*beta)\))\); \[IndentingNewLine] (*sum\ of\ upstream\ \
shares\ equals\ 1\ solved\ for\ q\ *) \[IndentingNewLine]thetatemp = 
        ty /. FindRoot[\((Sum[\((\((1 - ty - psi[ty, stemp[i], rtemp[i]])\)^
                          beta)\)*k[i], {i, 1, n}])\)^\((1 + 
                    a*eta)\) == \((Sum[\((\((ty - 
                              chi[ty, stemp[i], rtemp[i]])\)^eta)\)*g[i], {i, 
                      1, n}])\)^\((1 + a*beta)\), {ty, thetastart, 0.0, 
              1.0}]; \ \[IndentingNewLine]\[IndentingNewLine] (*\ Find\ q, \ 
        theta\ consistent\ with\ these\ values\ *) \[IndentingNewLine]\
\[IndentingNewLine] (*\ 
        Now\ compute\ shares\ that\ should\ prevail\ given\ the\ new\ values\ \
of\ q\ and\ theta, \ but\ take\ a\ half\ step\ *) \[IndentingNewLine]Do[
        s[i] = \((s[
                  i] + \((\((qtemp[
                          thetatemp]^\((\(-a\)*beta - 1)\))\)*\((\((1 - 
                            thetatemp - psi[thetatemp, stemp[i], rtemp[i]])\)^
                        beta)\)*k[i])\))\)/2; \[IndentingNewLine]\ \ \ \ \ r[
            i] = \((r[
                  i] + \((\((qtemp[
                          thetatemp]^\((\(-a\)*eta - 
                            1)\))\)*\((\((thetatemp - 
                            chi[thetatemp, stemp[i], rtemp[i]])\)^eta)\)*
                    g[i])\))\)/2, {i, 1, 
          n}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
        If\ we\ have\ a\ solution, \ 
        the\ calculation\ should\ give\ the\ same\ shares\ we\ started\ with\ \
*) \[IndentingNewLine]serror = Sum[\((stemp[i] - s[i])\)^2, {i, 1, n}]; 
      rerror = Sum[\((rtemp[i] - r[i])\)^2, {i, 1, n}]; \[IndentingNewLine]Do[
        stemp[i] = s[i]; rtemp[i] = r[i], {i, 1, n}]; \[IndentingNewLine]If[
        Sqrt[serror + rerror] < error, \ Break[]]; 
      thetastart = thetatemp; \[IndentingNewLine] (*\ 
        target\ error\ *) \[IndentingNewLine]bb = 
        iter;\[IndentingNewLine], {iter, 1, 
        10000}]\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Final\ calculations\ *) \[IndentingNewLine]
    \(q = qtemp[thetatemp];\)\[IndentingNewLine]
    \(t = thetatemp;\)\[IndentingNewLine] (*\ 
      The\ efficient\ quantity\ and\ intermediate\ good\ price\ \
*) \[IndentingNewLine]
    \(qe = 
        qq /. FindRoot[
            1 \[Equal] \((\((qq^\((a + \((1/beta)\))\))\)/\((Sum[
                          k[i], {i, 1, n}]^\((1/
                            beta)\))\))\) + \((\((qq^\((a + \((1/
                                eta)\))\))\)/\((Sum[
                          g[i], {i, 1, n}]^\((1/eta)\))\))\), {qq, 
              1}];\)\[IndentingNewLine]
    \(pe = \((qe^\((a + \((1/eta)\))\))\)/\((Sum[
                g[i], {i, 1, n}]^\((1/
                  eta)\))\);\)\[IndentingNewLine]\[IndentingNewLine]
    \(MHIold = 
        Sum[\((\((theta*\((1 - 
                        theta)\)*\((\((sb[i] - rb[i])\)^2)\)/\((eta*
                          beta)\))\) + \((a*\((1 - theta)\)*\((1 - 
                        rb[i])\) \((sb[i]^2)\)/beta)\) + \((a*
                    theta*\((1 - sb[i])\)*\((rb[i]^2)\)/
                      eta)\))\)/\((\((a*\((1 - sb[i])\)*\((1 - 
                        rb[i])\))\) + \((\((1 - theta)\)*\((1 - rb[i])\)/
                      beta)\) + \((theta*\((1 - sb[i])\)/eta)\))\), {i, 1, 
            n}];\)\[IndentingNewLine]
    \(MHI = 
        Sum[\((\((t*\((1 - 
                        t)\)*\((\((s[i] - r[i])\)^2)\)/\((eta*
                          beta)\))\) + \((a*\((1 - t)\)*\((1 - 
                        r[i])\) \((s[i]^2)\)/beta)\) + \((a*
                    t*\((1 - s[i])\)*\((r[i]^2)\)/
                      eta)\))\)/\((\((a*\((1 - s[i])\)*\((1 - 
                        r[i])\))\) + \((\((1 - t)\)*\((1 - r[i])\)/
                      beta)\) + \((t*\((1 - s[i])\)/eta)\))\), {i, 1, 
            n}];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      End\ computations, \ 
      start\ output\ *) \[IndentingNewLine]\[IndentingNewLine]
    Print["\< \>"]; Print["\< \>"];\[IndentingNewLine]
    \(If[Sqrt[serror + rerror] \[GreaterEqual] 
          error, \[IndentingNewLine]Print["\<Error: Failure to converge after \
\>", bb, "\< iterations. Approximate error in k: \>", 
          Sqrt[serror], "\< and gamma = \>", rerror]];\)\[IndentingNewLine]
    \(If[Sqrt[serror + rerror] \[GreaterEqual] error && 
          A > 1, \[IndentingNewLine]Print["\<This is most likely due to \
inelastic demand leading to non-existence.\>"]; 
        Print["\<\>"]];\)\[IndentingNewLine]\[IndentingNewLine]
    \(Print["\<Starting values\>"];\)\[IndentingNewLine]
    \(Print["\<Demand elasticity = \>", 
        If[a > 0, alpha, "\<infinite\>"], "\<, supply elasticity = \>", 
        eta, "\<, retailing Elasticity = \>", beta];\)\[IndentingNewLine]
    Print["\<Number of firms = \>", n]; 
    Print["\<Initial intermediate good price is \>", 
      theta];\[IndentingNewLine]
    \(If[type \[Equal] 1, 
        Print["\<The merger combines both upstream and downstream assets of \
firms 1 and 2\>"]];\)\[IndentingNewLine]
    \(If[type \[Equal] 2, 
        Print["\<The merger combines downstream assets of firms 1 and 2 but \
spins off 2's upstream assets.\>"]];\)\[IndentingNewLine]
    \(If[type \[Equal] 3, 
        Print["\<The merger combines upstream assets of firms 1 and 2 but \
spins off 2's downstream assets.\>"]];\)\[IndentingNewLine]
    \(Print["\< \>"];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Convert\ capitals\ to\ percents\ *) \[IndentingNewLine]
    ksum = Sum[k[i], {i, 1, n}]; gsum = Sum[g[i], {i, 1, n}]; 
    Do[k[i] = k[i]/ksum; g[i] = g[i]/gsum, {i, 1, n}];\[IndentingNewLine]
    kbsum = Sum[kb[i], {i, 1, n}]; gbsum = Sum[gb[i], {i, 1, n}]; 
    Do[kb[i] = kb[i]/kbsum; 
      gb[i] = gb[i]/gbsum, {i, 1, n}];\[IndentingNewLine]\[IndentingNewLine]
    \(Print["\<Before Merger\>"];\)\[IndentingNewLine]
    \(Do[Print["\<Firm \>", i, "\<: s[\>", i, "\<]=\>", 
          100*sb[i], "\<% r[\>", i, "\<]=\>", 100*rb[i], "\<% k[\>", 
          i, "\<]=\>", 100*kb[i], "\<% g[\>", i, "\<]=\>", 
          100*gb[i], "\<%\>"], {i, 1, n}];\)\[IndentingNewLine]
    \(Print["\< \>"];\)\[IndentingNewLine]\[IndentingNewLine]
    \(Print["\<After Merger\>"];\)\[IndentingNewLine]
    \(Do[Print["\<Firm \>", i, "\<: s[\>", i, "\<]=\>", 100*s[i], "\<% r[\>", 
          i, "\<]=\>", 100*r[i], "\<% k[\>", i, "\<]=\>", 
          100*k[i], "\<% g[\>", i, "\<]=\>", 100*g[i], "\<%\>"], {i, 1, 
          n}];\)\[IndentingNewLine]
    \(Print["\< \>"];\)\[IndentingNewLine]\[IndentingNewLine]
    \(Print["\<Statistics\>"];\)\[IndentingNewLine]
    \(Print["\<Intermediate good price goes from \>", theta, "\< to \>", 
        t];\)\[IndentingNewLine]
    \(Print["\<Change in intermediate good price is \>", 
        100.0*\((t - theta)\)/
            theta, "\<%\>"];\)\[IndentingNewLine]\[IndentingNewLine]
    \(Print["\<The efficient intermediate good price is \>", 
        pe];\)\[IndentingNewLine]
    \(Print["\<The quantity goes from \>", \ 
        100.0/qe, "\<% of full efficiency to \>", 
        100.0*q/qe, "\<%, which is a \>", 
        If[q < 1, 100*\((1 - q)\), 100.0*\((q - 1)\)], 
        If[q < 1, "\<% decrease\>", "\<% increase\>"], "\< in \
quantity.\>"];\)\[IndentingNewLine]\[IndentingNewLine]
    \(Print["\<MHI goes from \>", 100.0*MHIold, "\<% to \>", 
        100.0*MHI, "\<%.\>"];\)\[IndentingNewLine]
    \)\)\)], "Input"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("Starting values"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Demand elasticity = "\[InvisibleSpace]3\
\[InvisibleSpace]", supply elasticity = \
"\[InvisibleSpace]2\[InvisibleSpace]", retailing Elasticity = "\
\[InvisibleSpace]5\),
      SequenceForm[ 
      "Demand elasticity = ", 3, ", supply elasticity = ", 2, 
        ", retailing Elasticity = ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of firms = "\[InvisibleSpace]4\),
      SequenceForm[ "Number of firms = ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Initial intermediate good price is \
"\[InvisibleSpace]0.5`\),
      SequenceForm[ "Initial intermediate good price is ", .5],
      Editable->False]], "Print"],

Cell[BoxData[
    \("The merger combines both upstream and downstream assets of firms 1 and \
2"\)], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("Before Merger"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]1\[InvisibleSpace]": s["\
\[InvisibleSpace]1\[InvisibleSpace]"]="\[InvisibleSpace]40.`\[InvisibleSpace]\
"% r["\[InvisibleSpace]1\[InvisibleSpace]"]="\[InvisibleSpace]10.`\
\[InvisibleSpace]"% k["\[InvisibleSpace]1\[InvisibleSpace]"]="\
\[InvisibleSpace]48.86232939468279`\[InvisibleSpace]"% g["\[InvisibleSpace]1\
\[InvisibleSpace]"]="\[InvisibleSpace]7.793110826283635`\[InvisibleSpace]"%"\)\
,
      SequenceForm[ 
      "Firm ", 1, ": s[", 1, "]=", .4*^2, "% r[", 1, "]=", .1*^2, "% k[", 1, 
        "]=", 48.862329394682789, "% g[", 1, "]=", 7.7931108262836348, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]2\[InvisibleSpace]": s["\
\[InvisibleSpace]2\[InvisibleSpace]"]="\[InvisibleSpace]30.`\[InvisibleSpace]\
"% r["\[InvisibleSpace]2\[InvisibleSpace]"]="\[InvisibleSpace]20.`\
\[InvisibleSpace]"% k["\[InvisibleSpace]2\[InvisibleSpace]"]="\
\[InvisibleSpace]28.720796094526353`\[InvisibleSpace]"% g["\[InvisibleSpace]2\
\[InvisibleSpace]"]="\[InvisibleSpace]17.371784851503048`\[InvisibleSpace]"%"\
\),
      SequenceForm[ 
      "Firm ", 2, ": s[", 2, "]=", .3*^2, "% r[", 2, "]=", .2*^2, "% k[", 2, 
        "]=", 28.720796094526353, "% g[", 2, "]=", 17.371784851503048, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]3\[InvisibleSpace]": s["\
\[InvisibleSpace]3\[InvisibleSpace]"]="\[InvisibleSpace]20.`\[InvisibleSpace]\
"% r["\[InvisibleSpace]3\[InvisibleSpace]"]="\[InvisibleSpace]30.`\
\[InvisibleSpace]"% k["\[InvisibleSpace]3\[InvisibleSpace]"]="\
\[InvisibleSpace]15.740778050701229`\[InvisibleSpace]"% g["\[InvisibleSpace]3\
\[InvisibleSpace]"]="\[InvisibleSpace]29.459041047495415`\[InvisibleSpace]"%"\
\),
      SequenceForm[ 
      "Firm ", 3, ": s[", 3, "]=", .2*^2, "% r[", 3, "]=", .3*^2, "% k[", 3, 
        "]=", 15.740778050701229, "% g[", 3, "]=", 29.459041047495415, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]4\[InvisibleSpace]": s["\
\[InvisibleSpace]4\[InvisibleSpace]"]="\[InvisibleSpace]10.`\[InvisibleSpace]\
"% r["\[InvisibleSpace]4\[InvisibleSpace]"]="\[InvisibleSpace]40.`\
\[InvisibleSpace]"% k["\[InvisibleSpace]4\[InvisibleSpace]"]="\
\[InvisibleSpace]6.676096460089624`\[InvisibleSpace]"% g["\[InvisibleSpace]4\
\[InvisibleSpace]"]="\[InvisibleSpace]45.376063274717886`\[InvisibleSpace]"%"\
\),
      SequenceForm[ 
      "Firm ", 4, ": s[", 4, "]=", .1*^2, "% r[", 4, "]=", .4*^2, "% k[", 4, 
        "]=", 6.6760964600896244, "% g[", 4, "]=", 45.376063274717886, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("After Merger"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]1\[InvisibleSpace]": s["\
\[InvisibleSpace]1\[InvisibleSpace]"]="\[InvisibleSpace]60.20390076661065`\
\[InvisibleSpace]"% r["\[InvisibleSpace]1\[InvisibleSpace]"]="\
\[InvisibleSpace]30.186644958696736`\[InvisibleSpace]"% k["\[InvisibleSpace]1\
\[InvisibleSpace]"]="\[InvisibleSpace]77.58312548920915`\[InvisibleSpace]"% \
g["\[InvisibleSpace]1\[InvisibleSpace]"]="\[InvisibleSpace]25.164895677786685`\
\[InvisibleSpace]"%"\),
      SequenceForm[ 
      "Firm ", 1, ": s[", 1, "]=", 60.203900766610651, "% r[", 1, "]=", 
        30.186644958696736, "% k[", 1, "]=", 77.583125489209152, "% g[", 1, 
        "]=", 25.164895677786685, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]2\[InvisibleSpace]": s["\
\[InvisibleSpace]2\[InvisibleSpace]"]="\[InvisibleSpace]0\[InvisibleSpace]"% \
r["\[InvisibleSpace]2\[InvisibleSpace]"]="\[InvisibleSpace]0\[InvisibleSpace]\
"% k["\[InvisibleSpace]2\[InvisibleSpace]"]="\[InvisibleSpace]0\
\[InvisibleSpace]"% g["\[InvisibleSpace]2\[InvisibleSpace]"]="\
\[InvisibleSpace]0\[InvisibleSpace]"%"\),
      SequenceForm[ 
      "Firm ", 2, ": s[", 2, "]=", 0, "% r[", 2, "]=", 0, "% k[", 2, "]=", 0, 
        "% g[", 2, "]=", 0, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]3\[InvisibleSpace]": s["\
\[InvisibleSpace]3\[InvisibleSpace]"]="\[InvisibleSpace]26.190225378849046`\
\[InvisibleSpace]"% r["\[InvisibleSpace]3\[InvisibleSpace]"]="\
\[InvisibleSpace]30.087123299595635`\[InvisibleSpace]"% k["\[InvisibleSpace]3\
\[InvisibleSpace]"]="\[InvisibleSpace]15.740778050701229`\[InvisibleSpace]"% \
g["\[InvisibleSpace]3\[InvisibleSpace]"]="\[InvisibleSpace]29.459041047495415`\
\[InvisibleSpace]"%"\),
      SequenceForm[ 
      "Firm ", 3, ": s[", 3, "]=", 26.190225378849046, "% r[", 3, "]=", 
        30.087123299595635, "% k[", 3, "]=", 15.740778050701229, "% g[", 3, 
        "]=", 29.459041047495415, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Firm "\[InvisibleSpace]4\[InvisibleSpace]": s["\
\[InvisibleSpace]4\[InvisibleSpace]"]="\[InvisibleSpace]13.605873854540269`\
\[InvisibleSpace]"% r["\[InvisibleSpace]4\[InvisibleSpace]"]="\
\[InvisibleSpace]39.72623174170764`\[InvisibleSpace]"% k["\[InvisibleSpace]4\
\[InvisibleSpace]"]="\[InvisibleSpace]6.676096460089624`\[InvisibleSpace]"% \
g["\[InvisibleSpace]4\[InvisibleSpace]"]="\[InvisibleSpace]45.376063274717886`\
\[InvisibleSpace]"%"\),
      SequenceForm[ 
      "Firm ", 4, ": s[", 4, "]=", 13.605873854540269, "% r[", 4, "]=", 
        39.726231741707643, "% k[", 4, "]=", 6.6760964600896244, "% g[", 4, 
        "]=", 45.376063274717886, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(" "\)], "Print"],

Cell[BoxData[
    \("Statistics"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Intermediate good price goes from \
"\[InvisibleSpace]0.5`\[InvisibleSpace]" to \
"\[InvisibleSpace]0.47780860446468226`\),
      SequenceForm[ 
      "Intermediate good price goes from ", .5, " to ", .47780860446468226],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Change in intermediate good price is "\
\[InvisibleSpace]\(-4.438279107063547`\)\[InvisibleSpace]"%"\),
      SequenceForm[ 
      "Change in intermediate good price is ", -4.438279107063547, "%"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("The efficient intermediate good price is "\
\[InvisibleSpace]0.4954875853699908`\),
      SequenceForm[ 
      "The efficient intermediate good price is ", .49548758536999082],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("The quantity goes from \
"\[InvisibleSpace]88.29147072320308`\[InvisibleSpace]"% of full efficiency to \
"\[InvisibleSpace]84.11762121101457`\[InvisibleSpace]"%, which is a "\
\[InvisibleSpace]4.7273530251565`\[InvisibleSpace]"% decrease"\
\[InvisibleSpace]" in quantity."\),
      SequenceForm[ 
      "The quantity goes from ", 88.291470723203076, 
        "% of full efficiency to ", 84.117621211014566, "%, which is a ", 
        4.7273530251564999, "% decrease", " in quantity."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("MHI goes from "\[InvisibleSpace]7.606440516861858`\
\[InvisibleSpace]"% to \
"\[InvisibleSpace]9.94257296785228`\[InvisibleSpace]"%."\),
      SequenceForm[ 
      "MHI goes from ", 7.6064405168618583, "% to ", 9.9425729678522803, 
        "%."],
      Editable->False]], "Print"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 14055, 259, 3070, "Input"],
Cell[15834, 314, 36, 1, 25, "Print"],
Cell[15873, 317, 36, 1, 25, "Print"],
Cell[15912, 320, 50, 1, 25, "Print"],
Cell[15965, 323, 367, 8, 25, "Print"],
Cell[16335, 333, 159, 3, 25, "Print"],
Cell[16497, 338, 199, 4, 25, "Print"],
Cell[16699, 344, 109, 2, 25, "Print"],
Cell[16811, 348, 36, 1, 25, "Print"],
Cell[16850, 351, 48, 1, 25, "Print"],
Cell[16901, 354, 668, 11, 25, "Print"],
Cell[17572, 367, 670, 11, 25, "Print"],
Cell[18245, 380, 670, 11, 25, "Print"],
Cell[18918, 393, 669, 11, 25, "Print"],
Cell[19590, 406, 36, 1, 25, "Print"],
Cell[19629, 409, 47, 1, 25, "Print"],
Cell[19679, 412, 733, 12, 25, "Print"],
Cell[20415, 426, 584, 10, 25, "Print"],
Cell[21002, 438, 735, 12, 25, "Print"],
Cell[21740, 452, 733, 12, 25, "Print"],
Cell[22476, 466, 36, 1, 25, "Print"],
Cell[22515, 469, 45, 1, 25, "Print"],
Cell[22563, 472, 294, 6, 25, "Print"],
Cell[22860, 480, 270, 5, 25, "Print"],
Cell[23133, 487, 249, 5, 25, "Print"],
Cell[23385, 494, 558, 10, 25, "Print"],
Cell[23946, 506, 319, 7, 25, "Print"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

